# -*- coding: utf-8 -*-
##------------------------------------------
##   My Library datetime
##
##               2022.07.04 Masahiro Izutsu
##------------------------------------------
## my_datetime.py

import datetime
import my_logging

# 現在の日時文字列を得る
#   in:     form 文字列フォーマット (例 '%Y/%m/%d %H:%M:%S')
#   out:    現在の日時文字列
#
def now_strftime(form):
    now = datetime.datetime.now()
    return now.strftime(form)

# 日時の差を計算
#   in:     time        基準時刻(YY/mm/dd HH:MM:SS)
#           time_now    比較時刻(YY/mm/dd HH:MM:SS)
#           delta       経過秒数(seconds)
#   out:    day         日付の差(日 -999999999 から 999999999)
#           sec         秒の差　(秒 0 から 86399)
#
def time_difference(time, time_now) :
    dte = datetime.datetime.strptime(time, '%Y/%m/%d %H:%M:%S')
    dte0 = datetime.datetime.strptime(time_now, '%Y/%m/%d %H:%M:%S')
    dte1 = dte0 - dte
    return dte1.days, dte1.seconds

# 日時文字列のチェック
#   in:     time1       基準時刻(YY/mm/dd HH:MM:SS)
#           time2       比較時刻(YY/mm/dd HH:MM:SS)
#           delta       経過秒数(seconds)
#   out:    判定結果    True = 過ぎている False = 時間内
def time_check(time1, time2, delta=10) :
    day, sec = time_difference(time1, time2)
    result = True if day > 0 or sec > delta else False
    return result


#-----Test routine-----
# $ python3 my_datetime.py
#
if __name__ == "__main__":
    logsel = 1
    logger = my_logging.get_module_logger_sel(__name__, logsel)
    
    # Test 1 now_strftime
    form = '%Y/%m/%d %H:%M:%S'
    s = now_strftime(form)
    logger.info(f'now_strftime() >> {s}')

    # Test 2 time_difference
    time1 = '2022/07/03 23:59:20'
    time2 = '2022/07/04 00:00:20'
    day, sec = time_difference(time1, time2)
    logger.info(f'time_difference() {time1} - {time2} >> day = {day}, seconds = {sec}')

    # Test 3 time_difference
    time1 = '2022/07/03 00:00:20'
    time2 = '2022/07/04 00:00:20'
    day, sec = time_difference(time1, time2)
    logger.info(f'time_difference() {time1} - {time2} >> day = {day}, seconds = {sec}')

    # Test 4 time_check
    time1 = '2022/07/03 23:59:59'
    time2 = '2022/07/04 00:00:09'
    result = time_check(time1, time2, 10)
    logger.info(f'time_check() {time1} - {time2} >> {result}')

    # Test 4 time_check
    time1 = '2022/07/03 23:59:59'
    time2 = '2022/07/04 00:00:10'
    result = time_check(time1, time2, 10)
    logger.info(f'time_check() {time1} - {time2} >> {result}')


