# -*- coding: utf-8 -*-
##------------------------------------------
##   My GUI Dialog             Ver 0.02
##
##               2022.07.06 Masahiro Izutsu
##------------------------------------------
## my_dialog.py
##  ver 0.02    2022.07.16      大文字の拡張子(.JPG)にも対応

import sys
from tkinter import filedialog
import tkinter as tk
from tkinter import messagebox
from tkinter import simpledialog

# ディレクトリ選択
def select_dir(msg = ''):
    ttl = f'{msg} ディレクトリを選択'
    mustex = True
    initdir = './'
    dirname = dir_dialog(ttl, mustex, initdir)
    return dirname

# 画像ファイル選択
def select_image_file(msg = ''):
    ttl = f'{msg} 画像ファイルを選択'
    types = [("Image file", ".bmp .png .jpg .jpeg .JPG .tif .mp4"), ("Bitmap", ".bmp"), ("PNG", ".png"), ("JPEG", ".jpg"), ("JPEG", ".jpeg"), ("JPEG", ".JPG"), ("Tiff", ".tif") ]
    initdir = "./"
    filename = file_dialog(ttl, types, initdir)
    return filename

# 画像/動画ファイル選択
def select_image_movie_file(msg = ''):
    ttl = f'{msg} 画像/動画ファイルを選択'
    types = [("Image file", ".bmp .png .jpg .jpeg .JPG .tif .mp4"), ("Bitmap", ".bmp"), ("PNG", ".png"), ("JPEG", ".jpg"), ("JPEG", ".jpeg"), ("JPEG", ".JPG"), ("Tiff", ".tif"), ("MPEG", ".mp4") ]
    initdir = "./"
    filename = file_dialog(ttl, types, initdir)
    return filename

# ディレクトリの選択ダイアログ
def dir_dialog(ttl, mustex, initdir):
    root = tk.Tk()
    root.withdraw()
    dirname = filedialog.askdirectory(title = ttl, mustexist = mustex, initialdir = initdir)
    return dirname

# ファイルの選択ダイアログ
def file_dialog(ttl, types, initdir):
    root = tk.Tk()
    root.withdraw()
    filename = filedialog.askopenfilename(title = ttl, filetypes = types, initialdir = initdir)
    return filename

# 「情報」メッセージ・ダイアログ
#       out:    'ok'
def info_dialog(ttl, msg):
    root = tk.Tk()
    root.withdraw()
    result = messagebox.showinfo(ttl, msg)
    return result

# 「警告」メッセージ・ダイアログ
#       out:    'ok'
def warning_dialog(ttl, msg):
    root = tk.Tk()
    root.withdraw()
    result = messagebox.showwarning(ttl, msg)
    return result

# 「エラー」メッセージ・ダイアログ
#       out:    'ok'
def error_dialog(ttl, msg):
    root = tk.Tk()
    root.withdraw()
    result = messagebox.showerror(ttl, msg)
    return result

# 「はい・いいえ」メッセージ・ダイアログ
#       out:    True/False
def yesno_dialog(ttl, msg):
    root = tk.Tk()
    root.withdraw()
    result = messagebox.askyesno(ttl, msg)
    return result

# 「はい・いいえ」メッセージ・ダイアログ
#       out:    'yes'/'no'
def question_dialog(ttl, msg):
    root = tk.Tk()
    root.withdraw()
    result = messagebox.askquestion(ttl, msg)
    return result

# 「OK・キャンセル」メッセージ・ダイアログ
#       out:    True/False
def okcancel_dialog(ttl, msg):
    root = tk.Tk()
    root.withdraw()
    result = messagebox.askokcancel(ttl, msg)
    return result

# 「再試行・キャンセル」メッセージ・ダイアログ
#       out:    True/False
def retrycancel_dialog(ttl, msg):
    root = tk.Tk()
    root.withdraw()
    result = messagebox.askretrycancel(ttl, msg)
    return result

# 入力ダイアログ
#       out:    入力テキスト or None
def input_dialog(ttl, msg):
    root = tk.Tk()
    root.withdraw()
    result = simpledialog.askstring(ttl, msg)
    return result


#-----Test routine-----
# $ python3 my_dialog.py {option:0/1/2/3/4/5/6/7/8/9/10}
#
if __name__ == "__main__":
    import my_logging

    logger = my_logging.get_module_logger_sel(__name__, 1)
    args = sys.argv
    sel = '0' if len(args) <= 1 else args[1]

    if sel == '0':
        # select_dir()
        dirname = select_dir('「select_dir」')
        logger.debug(f'select_dir: {dirname}')

    elif sel == '1':
        # select_image_file()
        filename = select_image_file("「select_image_file」")
        logger.debug(f'select_image_file: {filename}')

    elif sel == '2':
        # select_image_movie_file()
        filename = select_image_file("「select_image_movie_file」")
        logger.debug(f'select_image_movie_file: {filename}')

    elif sel == '3':
        # info_dialog()
        ttl = 'messege box 情報'
        msg = 'メッセージ　************　　'
        result = info_dialog(ttl, msg)
        logger.debug(f'info_dialog: {result}')

    elif sel == '4':
        # warning_dialog()
        ttl = 'messege box 警告'
        msg = 'メッセージ　************　　'
        result = warning_dialog(ttl, msg)
        logger.debug(f'warning_dialog: {result}')

    elif sel == '5':
        # error_dialog()
        ttl = 'messege box エラー'
        msg = 'メッセージ　************　　'
        result = error_dialog(ttl, msg)
        logger.debug(f'error_dialog: {result}')

    elif sel == '6':
        # yesno_dialog()
        ttl = 'messege box はい・いいえ'
        msg = 'メッセージ　************　　'
        result = yesno_dialog(ttl, msg)
        logger.debug(f'yesno_dialog: {result}')

    elif sel == '7':
        # question_dialog()
        ttl = 'messege box はい・いいえ'
        msg = 'メッセージ　************　　'
        result = question_dialog(ttl, msg)
        logger.debug(f'question_dialog: {result}')

    elif sel == '8':
        # okcancel_dialog()
        ttl = 'messege box OK・キャンセル'
        msg = 'メッセージ　************　　'
        result = okcancel_dialog(ttl, msg)
        logger.debug(f'okcancel_dialog: {result}')

    elif sel == '9':
        # retrycancel_dialog()
        ttl = 'messege box 再試行・キャンセル'
        msg = 'メッセージ　************　　'
        result = retrycancel_dialog(ttl, msg)
        logger.debug(f'retrycancel_dialog: {result}')

    elif sel == '10':
        # input_dialog()
        ttl = 'messege box テキスト入力'
        msg = 'メッセージ　************　　'
        result = input_dialog(ttl, msg)
        logger.debug(f'input_dialog: {result}')


