# -*- coding: utf-8 -*-
##------------------------------------------
##   FPS calculation with OpenCV
##
##               2022.07.01 Masahiro Izutsu
##------------------------------------------
## my_fps.py        (mylib.py)

import cv2

## FPS 計測クラス
##
class fpsWithTick(object):
    def __init__(self):
        self._count     = 0
        self._oldCount  = 0
        self._freq      = 1000 / cv2.getTickFrequency()
        self._fps_total = 0
        self._startTime = cv2.getTickCount()

    def get(self):
        nowTime         = cv2.getTickCount()
        diffTime        = (nowTime - self._startTime) * self._freq
        self._startTime = nowTime
        fps             = (self._count - self._oldCount) / (diffTime / 1000.0)
        self._fps_total += fps
        self._oldCount  = self._count
        self._count     += 1
        fpsRounded      = round(fps, 1)
        return fpsRounded

    def get_average(self):
        if (self._oldCount == 0):
            averageRounded  = -1
        else:
            average         = self._fps_total / self._oldCount
            averageRounded  = round(average, 1)
        return averageRounded

    def get_count(self):
        return self._oldCount

#-----Test routine-----
# $ python3 my_fps.py
#
if __name__ == "__main__":
    cap = cv2.VideoCapture(0)
    window_name = 'FPS test'
    cv2.namedWindow(window_name, flags=cv2.WINDOW_AUTOSIZE | cv2.WINDOW_GUI_NORMAL) 
    fpsWithTick = fpsWithTick()             # 初期化

    while True:
        ret, src = cap.read()
        if not ret:
            print('The camera cannot be opened !!')
            quit()

        cv2.imshow(window_name, src)
        fps = fpsWithTick.get()             # FPSを計算する
        count = fpsWithTick.get_count()
        if (count != 0):
            print(fps)
        k = cv2.waitKey(30) & 0xff

        if k == 27:  # ESC key
            break
    cap.release()
    cv2.destroyAllWindows()

    print('FPS average: {:.2f}'.format(fpsWithTick.get_average()))


