# -*- coding: utf-8 -*-
##------------------------------------------
##   My Library Logging
##
##               2022.06.28 Masahiro Izutsu
##------------------------------------------
## my_logging.py

from logging import getLogger, Formatter, StreamHandler, FileHandler, DEBUG, INFO, WARNING, ERROR, CRITICAL

## 出力ログの登録
## in   loglevel: DEBUG/INFO/WARNING/ERROR/CRITICAL
##      formsel: フォーマットタイプ
##          0: mylogging: Process Start!
##          1: mylogging:60 [INFO]: Process Start!
##          2: 2022-06-30 15:22:23,272 __main__:60 <module> [INFO]: Process Start!
## out  logging オブジェクト
##
def get_module_logger(module, loglevel, formsel = 2):
    logger = getLogger(module)
    logger = _set_handler(logger, StreamHandler(), loglevel, formsel)
    logger.setLevel(DEBUG)
    logger.propagate = False
    return logger

def _set_handler(logger, handler, loglevel, formsel):
    handler.setLevel(loglevel)
    if formsel == 0:
        handler.setFormatter(Formatter('%(message)s'))
    elif formsel == 1:
        handler.setFormatter(Formatter('%(module)s:%(lineno)s [%(levelname)s]: %(message)s'))
    elif formsel == 2:
        handler.setFormatter(Formatter('%(asctime)s %(name)s:%(lineno)s %(funcName)s [%(levelname)s]: %(message)s'))
    logger.addHandler(handler)
    return logger

## 出力ログの選択登録
## in   logsel: loglevel    formsel
##         -1    ERROR       2
##          0    DEBUG       0
##          1    DEBUG       1
##          2    DEBUG       2
##          3    INFO        0
##          4    INFO        1
##          5    INFO        2
## out  logging オブジェクト
##
def get_module_logger_sel(module, logsel):
    loglevel = DEBUG
    formsel = 2
    if logsel == -1:
        loglevel = ERROR
        formsel = 2
    elif logsel == 0:
        loglevel = DEBUG
        formsel = 0
    elif logsel == 1:
        loglevel = DEBUG
        formsel = 1
    elif logsel == 2:
        loglevel = DEBUG
        formsel = 2
    elif logsel == 3:
        loglevel = INFO
        formsel = 0
    elif logsel == 4:
        loglevel = INFO
        formsel = 1
    elif logsel == 5:
        loglevel = INFO
        formsel = 2

    logging = get_module_logger(module, loglevel, formsel)
    return logging


#-----Test routine-----
# $ python3 my_logging.py {option:0/1/2/3/4/5}
#
if __name__ == "__main__":
    import sys
    args = sys.argv
    logsel = -1 if len(args) <= 1 else int(args[1])
    logger = get_module_logger_sel(__name__, logsel)
    
    logger.info('Process Start!')
    logger.debug('debug')
    logger.info('info')
    logger.warning('warning')
    logger.error('error')
    logger.info('Process End!')
