# -*- coding: utf-8 -*-
##------------------------------------------
##   My Library Text Convert    Ver 0.05
##
##               2022.01.17 Masahiro Izutsu
##------------------------------------------
## my_txtconv.py       (mylib_text.py)
##      Ver 0.01    「令和」対応          2022.02.19
##      Ver 0.04    辞書ファイル対応      2022.04.12
##                      変換前文字列1,変換後文字列1
##                      変換前文字列2,変換後文字列2
##                          :
##      Ver 0.05    ログ出力変更          2022.09.18

import re
import datetime
import csv
import my_csv
import my_logging

ENCORDING = 'utf_8_sig'
DIC_FILE_PASS = 'mylib_test/'
DIC_KEY_FILE = 'dic_key.txt'
DIC_TITLE_FILE = 'dic_title.txt'
DIC_COMPANY_FILE = 'dic_company.txt'
DIC_DATE_FILE = 'dic_date.txt'

class TextConvert:
    logger = None
    logsel = 0
    dic_key = ''
    dic_title = ''
    dic_company = ''
    dic_date = ''

    # 初期化
    #   logsel:     ログ出力レベル
    def __init__(self, dicpass = '', logsel = 4):
        self.logger = my_logging.get_module_logger_sel(__name__, logsel)
        self.dic_key = dicpass + DIC_KEY_FILE
        self.dic_title = dicpass + DIC_TITLE_FILE
        self.dic_company = dicpass + DIC_COMPANY_FILE
        self.dic_date = dicpass + DIC_DATE_FILE
        self.logsel = logsel

    def _get_logger_object(self):
        return self.logger


    # 文字列から数字を取り出す  out: 数字のリスト  error=空のリスト
    def get_str2num(self, text):
        result = re.findall(r"\d+", text)
        return result

    # 年月日の数値の妥当性を調べる  out: 文字列  error=''
    def checkDate(self, year, month, day):
        try:
            str = datetime.date(int(year), int(month), int(day))
            string = str.strftime('%Y/%m/%d')
        except ValueError:
            string = ''
            self.logger.debug('checkDate(): Invalid string error !!')
        return string

    # 文字列が年月日かどうかを調べる(「令和」対応)  out: 文字列  error=''
    def get_str2date(self, text):
        string = ''
        text = re.sub('[,.、]', '', text)
        text = self.replace_day_strings(text, False)
        result = self.get_str2num(text)
        if len(result) == 3:
            if int(result[0]) < 2000:
                text = self.remove_space(text)
                result = self.get_str2num(text)
        if len(result) != 3:
            text = self.remove_space(text)
            result = self.get_str2num(text)
        if len(result) == 3:
            if text.find('令和') == 0:
                reiwa = int(result[0]) + 2018
                result[0] = str(reiwa)
            string = self.checkDate(result[0], result[1], result[2])

        elif len(result) == 2:
            if text.find('令和元年') == 0:
                result.insert(0, 2019)
                string = self.checkDate(result[0], result[1], result[2])

        else:
            self.logger.debug('get_str2date(): Invalid string error !!')

        return string

    # 文字列から金額を取り出す  out: 文字列  error=''
    def get_str2mony(self, text):
        text = re.sub('[CcoO]', '0', text)
        text0 = self.remove_space(text)
        money = ''
        if len(text0) > 0:
            txt = re.sub('[,.、]', '', text0)
            if len(txt) > 0:
                result = self.get_str2num(txt)
                if len(result) == 1:
                    money = str(result[0])
        return money

    # 文字列の空白を取る  out: 文字列  error=''
    def remove_space(self, text):
        string = re.sub(r"[\u3000 \t]", "", text)
        return string


    def remove_crlf(self, text):
        text = text.replace('\n', '')
        return text

    # よくある誤読をヒューリスティックに訂正(キー文字列)
    def replace_key_strings(self, text, logf = True):
        text_org = text
        text = self.remove_space(text)
        text = re.sub('[。_.-<-”]', '', text)

        mycsv = my_csv.CSVtreatment(self.dic_key, ENCORDING, self.logsel)
        befor, after = mycsv.read_list2_csv()
        n = len(befor)
        if n > 0:
            for i in range(n):
                text = text.replace(befor[i], after[i])
                text = text.replace(u'請請求書', u'請求書')
        if logf:
            logger.debug(f'replace_key_strings(): {text_org} →  {text}')
        return text

    # よくある誤読をヒューリスティックに訂正(タイトル)
    def replace_Title_strings(self, text, logf = True):
        text_org = text
        text = self.remove_crlf(text)
        text = self.remove_space(text)
        text = re.sub('[。、_|]', '', text)

        mycsv = my_csv.CSVtreatment(self.dic_title, ENCORDING, self.logsel)
        befor, after = mycsv.read_list2_csv()
        n = len(befor)
        if n > 0:
            for i in range(n):
                text = text.replace(befor[i], after[i])
                text = text.replace(u'ソソフトウェア', u'ソフトウェア')
                text = text.replace(u'ソフブソフトウェア', u'ソフトウェア')
                text = text.replace(u'ソフソフトウェア', u'ソフトウェア')
        if logf:
            logger.debug(f'replace_Title_strings(): {text_org} →  {text}')
        return text

    # よくある誤読をヒューリスティックに訂正(会社名)
    def replace_company_strings(self, text, logf = True):
        text_org = text
        text = self.remove_crlf(text)
        text = self.remove_space(text)
        text = re.sub("[$@&=]","", text)
        text = re.sub('[。、_,|0]', '', text)

        mycsv = my_csv.CSVtreatment(self.dic_company, ENCORDING, self.logsel)
        befor, after = mycsv.read_list2_csv()
        n = len(befor)
        if n > 0:
            for i in range(n):
                text = text.replace(befor[i], after[i])
        if logf:
            logger.debug(f'replace_company_strings(): {text_org} →  {text}')
        return text

    # よくある誤読をヒューリスティックに訂正(日付)
    def replace_day_strings(self, text, logf = True):
        text_org = text
        mycsv = my_csv.CSVtreatment(self.dic_date, ENCORDING, self.logsel)
        befor, after = mycsv.read_list2_csv()
        n = len(befor)
        if n > 0:
            for i in range(n):
                text = text.replace(befor[i], after[i])
        if logf:
            logger.debug(f'replace_company_strings(): {text_org} →  {text}')
        return text


#-----Test routine-----
# $ python3 my_txtconv.py
#
if __name__ == "__main__":
    logsel = 0
    my_text_convert = TextConvert(DIC_FILE_PASS, logsel)
    logger = my_text_convert._get_logger_object()

    def _get_str2date(s):
        s0 = my_text_convert.get_str2date(s)
        logger.debug(f' get_str2date(): {s} → {s0}')

    def _checkDate(year, month,day):
        s0 = my_text_convert.checkDate(year, month,day)
        logger.debug(f' checkDate(): {year}, {month}, {day} → {s0}')

    def _get_str2mony(s):
        s0 = my_text_convert.get_str2mony(s)
        logger.debug(f' get_str2mony(): {s} → {s0}')

    def _get_str2num(s):
        s0 = my_text_convert.get_str2num(s)
        logger.debug(f' get_str2num(): {s} → {s0}')

    def _remove_space(s):
        s0 = my_text_convert.remove_space(s)
        logger.debug(f' remove_space(): {s} → {s0}')

    # 日付文字列
    s = '信和 元 年 8 月 31 日'
    _get_str2date(s)
    s = '2020 年 06 月 80 日'
    _get_str2date(s)
    s = '2022年1月17日'
    _get_str2num(s)
    s = '年月日'
    _get_str2num(s)

    year = 2022
    month = 2
    day = 31
    _checkDate(year, month,day)
    month = 1
    _checkDate(year, month,day)

    s = '2022年1月17日'
    _get_str2date(s)
    s = '2022年2月31日'
    _get_str2date(s)
    s = '2月31日'
    _get_str2date(s)
    s = '20,22年1月31日'
    _get_str2date(s)
    s = '令和元年1月2日'
    _get_str2date(s)
    s = '令和4年2月14日'
    _get_str2date(s)
    s = '令 和 元 年 8 月 31 日'
    _get_str2date(s)
    s = '2021 12 31'
    _get_str2date(s)
    s = '令 和 3 年 12 月 31 日'
    _get_str2date(s)
    #----------------

    s = ' \8,500'
    _get_str2mony(s)
    s = '590, 000'
    _get_str2mony(s)
    s = '\\637, 200'
    _get_str2mony(s)
    s = '615、600'
    _get_str2mony(s)
    s = '1, 259, 020'
    _get_str2mony(s)
    s = '526.845'
    _get_str2mony(s)
    s = '2,070, 490'
    _get_str2mony(s)
    s = '2, 277, 939'
    _get_str2mony(s)
    #----------------

    s = '請 求 書'
    _remove_space(s)
    s = '講 求 書'
    my_text_convert.replace_key_strings(s)
    s = '請 。 求 書'
    my_text_convert.replace_key_strings(s)
    s = '請 _ 求 _ 書'
    my_text_convert.replace_key_strings(s)
    s = '著 求 書'
    my_text_convert.replace_key_strings(s)
    s = 'ジブフトウェア'
    my_text_convert.replace_Title_strings(s)
    s = 'アプクシアプアソフトデザイン'
    my_text_convert.replace_company_strings(s)
    s = 'PPFパパートナーズ'
    my_text_convert.replace_company_strings(s)
    s = '株式会会社ントラル情報サービス'
    my_text_convert.replace_company_strings(s)
    s = 'フトウェア開発'
    my_text_convert.replace_Title_strings(s)
    s = 'ソソフトウェア開発'
    my_text_convert.replace_Title_strings(s)
    s = 'インター・ラボ株式会社='
    my_text_convert.replace_company_strings(s)
    s = 'ソフブフトウェア'
    my_text_convert.replace_Title_strings(s)
    s = '2020 年 06 月 90 日'
    _get_str2date(s)
    s = '2019 の 31'
    _get_str2date(s)
    s = '2,520, 00C'
    _get_str2mony(s)
    s = '峡 <- 求 書'
    my_text_convert.replace_key_strings(s)
    s = '針 和 3 年 12 月 31 日'
    _get_str2date(s)
    s = '2 トウェア 開発 業務'
    my_text_convert.replace_Title_strings(s)
    s = 'トウェア開発業務'
    my_text_convert.replace_Title_strings(s)


